# src/tutompy/wikipedia.py
"""Client for the Wikipedia REST API, version 1."""
from dataclasses import dataclass

import click
import desert
import marshmallow
import requests


API_URL: str = "https://{language}.wikipedia.org/api/rest_v1/page/random/summary"


@dataclass
class Page:
    """Page resource.

    Attributes:
        title: The title of the Wikipedia page.
        extract: A plain text summary.
    """

    title: str
    extract: str


schema = desert.schema(Page, meta={"unknown": marshmallow.EXCLUDE})


def random_page(language: str = "en") -> Page:
    """Return a random page.

    Performs a GET request to the /page/random/summary endpoint.

    Args:
        language: The Wikipedia language edition. By default, English
        Wikipedia is used ("en").

    Returns:
        A page resource.

    Raises:
        ClickException: The HTTP request failed or the HTTP response
        contained an invalid body.

    Example:
        >>> from tutompy import wikipedia
        >>> page = wikipedia.random_page(language="en")
        >>> bool(page.title)
        True
    """
    url = API_URL.format(language=language)

    try:
        with requests.get(url) as response:
            response.raise_for_status()
            data = response.json()
            return schema.load(data)
    except (requests.RequestException, marshmallow.ValidationError) as error:
        message = str(error)
        raise click.ClickException(message)



# -*- coding: utf-8 -*-
from setuptools import setup

package_dir = \
{'': 'src'}

packages = \
['tutompy']

package_data = \
{'': ['*']}

install_requires = \
['click>=7.1.2,<8.0.0',
 'desert>=2020.11.18,<2021.0.0',
 'marshmallow>=3.11.1,<4.0.0',
 'requests>=2.25.1,<3.0.0']

entry_points = \
{'console_scripts': ['tutompy = tutompy.console:main']}

setup_kwargs = {
    'name': 'tutompy',
    'version': '0.1.0',
    'description': 'The hypermodern Python project',
    'long_description': '# tutompy\n[![Tests](https://github.com/pamlinux/tutompy/workflows/Tests/badge.svg)](https://github.com/pamlinux/tutompy/actions?workflow=Tests)\n[![Codecov](https://codecov.io/gh/pamlinux/tutompy/branch/master/graph/badge.svg)](https://codecov.io/gh/pamlinux/tutompy)\nMy repository for hypermodern-python tutorial by Claudio Jolowicz\n',
    'author': 'Pierre-Alain Moret',
    'author_email': 'moret.pierre.alain@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/pamlinux/tutompy',
    'package_dir': package_dir,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)
